@@ -1,10 +1,9 @@
 /* GDA Common Library
- * Copyright (C) 1998 - 2006 The GNOME Foundation.
+ * Copyright (C) 1998-2003 The GNOME Foundation.
  *
  * Authors:
  *	 Juan-Mariano de Goyeneche <jmseyas@dit.upm.es>
  *	 Gonzalo Paniagua Javier (gonzalo@gnome-db.org)
- *       Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -27,108 +26,26 @@
  */
 
 #include "gda-blob.h"
-#include "gda-value.h"
-
-#define PARENT_TYPE G_TYPE_OBJECT
-#define CLASS(blob) (GDA_BLOB_CLASS (G_OBJECT_GET_CLASS (blob)))
-static void gda_blob_class_init (GdaBlobClass *klass);
-static void gda_blob_init       (GdaBlob *provider, GdaBlobClass *klass);
-static void gda_blob_finalize   (GObject *object);
-
-static GObjectClass *parent_class = NULL;
-
-static void 
-blob_to_string (const GValue *src, GValue *dest) 
-{
-	GdaBlob *gdablob;
-	
-	g_return_if_fail (G_VALUE_HOLDS_STRING (dest) &&
-			  GDA_VALUE_HOLDS_BLOB (src));
-	
-	gdablob = (GdaBlob *) gda_value_get_blob ((GValue *) src);
-	
-	g_value_set_string (dest, gda_blob_get_sql_id (gdablob));
-}
-
-GType
-gda_blob_get_type (void)
-{
-        static GType type = 0;
-
-        if (!type) {
-                static const GTypeInfo info = {
-                        sizeof (GdaBlobClass),
-                        (GBaseInitFunc) NULL,
-                        (GBaseFinalizeFunc) NULL,
-                        (GClassInitFunc) gda_blob_class_init,
-                        NULL,
-                        NULL,
-                        sizeof (GdaBlob),
-                        0,
-                        (GInstanceInitFunc) gda_blob_init
-                };
-
-                type = g_type_register_static (PARENT_TYPE, "GdaBlob", &info, G_TYPE_FLAG_ABSTRACT);
-
-		g_value_register_transform_func (G_TYPE_STRING,
-						 type,
-						 blob_to_string);
-
-        }
-        return type;
-}
-
-static void
-gda_blob_class_init (GdaBlobClass *klass)
-{
-        GObjectClass *object_class = G_OBJECT_CLASS (klass);
-
-        parent_class = g_type_class_peek_parent (klass);
-
-        object_class->finalize = gda_blob_finalize;
-        klass->open = NULL;
-        klass->read = NULL;
-        klass->write = NULL;
-        klass->lseek = NULL;
-        klass->close = NULL;
-        klass->remove = NULL;
-        klass->get_sql_id = NULL;
-}
-
-static void
-gda_blob_init (GdaBlob *provider, GdaBlobClass *klass)
-{
-
-}
-
-static void
-gda_blob_finalize (GObject *object)
-{
-	/* chain to parent class */
-        parent_class->finalize (object);
-}
-
 
 /**
  * gda_blob_open
- * @blob: an existing #GdaBlob
+ * @blob: a #GdaBlob structure obtained from a #GdaValue or allocated by the
+ * user when he/she wants to create a new #GdaBlob.
  * @mode: see #GdaBlobMode.
  *
  * Opens an existing BLOB. The BLOB must be initialized by
- * #gda_connection_create_blob or obtained from a #GValue.
+ * #gda_connection_create_blob or obtained from a #GdaValue.
  * 
  * Returns: 0 if everything's ok. In case of error, -1 is returned and the
- * provider should have added an error (a #GdaConnectionEvent) to the connection.
+ * provider should have added an error to the connection.
  */
 gint 
 gda_blob_open (GdaBlob *blob, GdaBlobMode mode)
 {
-	g_return_val_if_fail (blob && GDA_IS_BLOB (blob), -1);
+	g_return_val_if_fail (blob != NULL, -1);
+	g_return_val_if_fail (blob->open != NULL, -1);
 
-	if (CLASS (blob)->open != NULL)
-		return CLASS (blob)->open (blob, mode);
-	else
-		return -1;
+	return blob->open (blob, mode);
 }
 
 /**
@@ -146,12 +63,10 @@ gda_blob_open (GdaBlob *blob, GdaBlobMode mode)
 gint
 gda_blob_read (GdaBlob *blob, gpointer buf, gint size, gint *bytes_read)
 {
-	g_return_val_if_fail (blob && GDA_IS_BLOB (blob), -1);
+	g_return_val_if_fail (blob != NULL, -1);
+	g_return_val_if_fail (blob->read != NULL, -1);
 
-	if (CLASS (blob)->read != NULL)
-		return CLASS (blob)->read (blob, buf, size, bytes_read);
-	else
-		return -1;
+	return blob->read (blob, buf, size, bytes_read);
 }
 
 /**
@@ -169,12 +84,10 @@ gda_blob_read (GdaBlob *blob, gpointer buf, gint size, gint *bytes_read)
 gint
 gda_blob_write (GdaBlob *blob, gpointer buf, gint size, gint *bytes_written)
 {
-	g_return_val_if_fail (blob && GDA_IS_BLOB (blob), -1);
+	g_return_val_if_fail (blob != NULL, -1);
+	g_return_val_if_fail (blob->write != NULL, -1);
 
-	if (CLASS (blob)->write != NULL)
-		return CLASS (blob)->write (blob, buf, size, bytes_written);
-	else
-		return -1;
+	return blob->write (blob, buf, size, bytes_written);
 }
 
 /**
@@ -191,12 +104,10 @@ gda_blob_write (GdaBlob *blob, gpointer buf, gint size, gint *bytes_written)
 gint 
 gda_blob_lseek (GdaBlob *blob, gint offset, gint whence)
 {
-	g_return_val_if_fail (blob && GDA_IS_BLOB (blob), -1);
+	g_return_val_if_fail (blob != NULL, -1);
+	g_return_val_if_fail (blob->lseek != NULL, -1);
 
-	if (CLASS (blob)->lseek != NULL)
-		return CLASS (blob)->lseek (blob, offset, whence);
-	else
-		return -1;
+	return blob->lseek (blob, offset, whence);
 }
 
 /**
@@ -211,12 +122,10 @@ gda_blob_lseek (GdaBlob *blob, gint offset, gint whence)
 gint 
 gda_blob_close (GdaBlob *blob)
 {
-	g_return_val_if_fail (blob && GDA_IS_BLOB (blob), -1);
+	g_return_val_if_fail (blob != NULL, -1);
+	g_return_val_if_fail (blob->close != NULL, -1);
 
-	if (CLASS (blob)->close != NULL)
-		return CLASS (blob)->close (blob);
-	else
-		return -1;
+	return blob->close (blob);
 }
 
 /**
@@ -232,27 +141,26 @@ gda_blob_close (GdaBlob *blob)
 gint 
 gda_blob_remove (GdaBlob *blob)
 {
-	g_return_val_if_fail (blob && GDA_IS_BLOB (blob), -1);
+	g_return_val_if_fail (blob != NULL, -1);
+	g_return_val_if_fail (blob->remove != NULL, -1);
 
-	if (CLASS (blob)->remove != NULL)
-		return CLASS (blob)->remove (blob);
-	else
-		return -1;
+	return blob->remove (blob);
 }
 
 /**
- * gda_blob_get_sql_id
+ * gda_blob_free_data
  * @blob: a valid #GdaBlob.
  *
- * Returns a string representation of a @blob's SQL ID.
+ * Let the provider free any internal data stored in @blob. The user
+ * is still responsible for deallocating @blob itself.
+ *
  */
-gchar*
-gda_blob_get_sql_id (GdaBlob *blob) 
+void 
+gda_blob_free_data (GdaBlob *blob)
 {
-	g_return_val_if_fail(blob && GDA_IS_BLOB (blob), NULL);
+	g_return_if_fail (blob != NULL);
+	g_return_if_fail (blob->free_data != NULL);
 
-	if (CLASS (blob)->get_sql_id != NULL)
-		return CLASS (blob)->get_sql_id (blob);
-	else
-		return NULL;
+	blob->free_data (blob);
 }
+
